Index: branches/eam_branches/ipp-20130307/dvodist/www-util/ippdata.page.mkd
===================================================================
--- branches/eam_branches/ipp-20130307/dvodist/www-util/ippdata.page.mkd	(revision 35271)
+++ branches/eam_branches/ipp-20130307/dvodist/www-util/ippdata.page.mkd	(revision 35272)
@@ -12,7 +12,7 @@
 $fromProxy = $_SERVER['HTTP_X_FORWARDED_FOR'] && ($_SERVER['REMOTE_ADDR'] == $ifaProxy);
 if ($fromProxy) {
-  $rootdir = "";
+  $rootdir = "@ROOTWWW@";
  } else {
-  $rootdir = "@ROOTDIR@";
+  $rootdir = "@ROOTWWW@/@ROOTDIR@";
  }
 

Index: branches/eam_branches/ipp-20130307/dvodist/www-util/ipp.php
===================================================================
--- branches/eam_branches/ipp-20130307/dvodist/www-util/ipp.php	(revision 35271)
+++ branches/eam_branches/ipp-20130307/dvodist/www-util/ipp.php	(revision 35272)
@@ -1,5 +1,3 @@
 <?php
-
-global $rootdir;
 
 function head ($title) {
@@ -24,5 +22,5 @@
   if (! $project) { $project = "none"; }
 
-  // echo "<p style=\"font-size:50%\">host: $WWWHOST, db: $DBHOST</p>\n";
+  // echo "<p style=\"font-size:50%\">host: $root</p>\n";
   echo "<table class=page cellspacing=10px><tr><td valign=top>\n";
   echo "<table class=menu cellspacing=0px>\n";
@@ -76,9 +74,7 @@
     } 
 
-    global $rootdir;
-
     // hi-lite the current page (use select-style, not style)
     $thisname = $_SERVER[SCRIPT_NAME]; 
-    $page = $rootdir . $base;
+    $page = $root . $base;
     if ($page == $thisname) {
       $style = trim($line[1]);
@@ -92,5 +88,5 @@
       break;
     case 'picture':
       // prepend the rootdir if needed (reference to /)
       if ($name[0] == '/') {
 	$name = $root . $name;
@@ -99,5 +95,5 @@
       break;
     case 'piclink':
       // prepend the rootdir if needed (reference to /)
       if ($name[0] == '/') {
 	$name = $root . $name;
@@ -92,5 +88,5 @@
       break;
     case 'picture':
-      // prepend the rootdir if needed (reference to /)
+      // prepend the root if needed (reference to /)
       if ($name[0] == '/') {
 	$name = $root . $name;
@@ -99,5 +95,5 @@
       break;
     case 'piclink':
-      // prepend the rootdir if needed (reference to /)
+      // prepend the root if needed (reference to /)
       if ($name[0] == '/') {
 	$name = $root . $name;